@@ -8,6 +8,7 @@ from .tools import handle_abnormal
 from .db_connect import DBConnect
 import logging
 import platform
+import copy
 
 logging.basicConfig(
     level=logging.WARNING,
@@ -34,10 +35,33 @@ def set_token_session(app, verify, per_defaults: list, whitelist: list = []):
         session['token_id'] = user['token_id']
         session['user_name'] = user['user_name']
         session['real_name'] = user['real_name']
+
+        # 根据用户分组权限，设置相关查询过滤条件
+        meta_auth = {}
+        # 从环境变量中获取超级管理员账号信息
+        admin_user = os.environ.get('ADMIN_USER', [])
+        # 判断用户是否为超级管理员，超级管理员则跳过群组认证环节
+        if user['user_name'] in admin_user:
+            pass
+        elif verify.group_list:
+            meta_auth.update(group_list={'$elemMatch': {'$in': verify.group_list}})
+        else:
+            handle_abnormal(message='用户无任何群组权限，无法操作数据', status=403)
+
+        # 根据模块保存对应权限（增删改查权限，群组权限，个人权限）
         for per in per_defaults:
+            # 深拷贝处理分组权限条件数据
+            auth_filter = copy.deepcopy(meta_auth)
+            # 获取模块对应页面权限
             session[per['session_key']] = verify.permission_verify(
                 per['center_name'], per['permission_name'])
-        if verify.group_list == None:
+            # 判断页面是否为个人权限，个人权限则添加创建人搜索条件
+            if not session[per['session_key']]['is_all_data']:
+                auth_filter.update(creator=user['user_name'])
+            # 根据用户的分组权限，个人权限设置数据赛选条件，写入session
+            session[per['session_key']].update(auth_filter=auth_filter)
+
+        if verify.group_list is None:
             verify.group_list = []
         session['group_list'] = verify.group_list
 
@@ -183,8 +207,6 @@ class VerifyToken:
                     self.mongo_user),
                 status=500,
             )
-        permission_list = []
-        is_all_data = False
         user = self.user_db.find_docu_by_id(id=self.uid)  # 查询用户对应的角色数据
         role_name_list = user['role_name']  # 用户包含的所有角色名称
         self.group_list = user['group_name']  # 用户包含的所有组别名称
